@@ -33,19 +33,11 @@ use crate::{
 };
 
 /// Framework for auto-loading Cargo projects from the repository contents.
-#[derive(Debug)]
+#[derive(Debug, Default)]
 pub struct CargoLoader {
     shortest_toml_dirname: Option<RepoPathBuf>,
 }
 
-impl Default for CargoLoader {
-    fn default() -> Self {
-        CargoLoader {
-            shortest_toml_dirname: None,
-        }
-    }
-}
-
 impl CargoLoader {
     /// Process items in the Git index while auto-loading projects. Since we use
     /// `cargo metadata` to get project information, all we do here is find the
